import { Comment } from '../models/Comment';

export class CommentParser {
    /**
     * Extracts Reddit usernames from the body of a single comment.
     * @param comment A single Comment object to be processed.
     * @returns An array of unique Reddit usernames found in the comment.
     */
    public static extractUsernames(comment: Comment): string[] {
        const regexPattern: RegExp = /(^|\s|\\r\\n|\\t|[".,;(){}\[\]!?@#])(\/?u\/[a-zA-Z0-9_]+)/g;
        const foundUsernames: Set<string> = new Set();

        const matches = comment.body.match(regexPattern);
        if (matches) {
            matches.forEach(match => {
                // Ensure the username is captured in a standardized format
                const usernameMatch = match.trim().match(/\/?u\/([a-zA-Z0-9_]+)/);
                if (usernameMatch) {
                    // Standardize to "username" format
                    const username = `${usernameMatch[1].toLowerCase()}`;
                    foundUsernames.add(username);
                }
            });
        }

        return Array.from(foundUsernames);
    }
}
